diff --git a/googledatastore/README.md b/googledatastore/README.md
index 0c52f576015944bceedddf8dbb4590b3fbcfdd3d..a6755a6522ee100c5ab1a3c3ebad088a2ba31d7b 100644
--- a/googledatastore/README.md
+++ b/googledatastore/README.md
@@ -1,5 +1,5 @@
 <!--
-Copyright (c) 2010 Yahoo! Inc., 2012 - 2015 YCSB contributors.
+Copyright (c) 2015 YCSB contributors.
 All rights reserved.
 
 Licensed under the Apache License, Version 2.0 (the "License"); you
diff --git a/googledatastore/conf/googledatastore.properties b/googledatastore/conf/googledatastore.properties
index 0f1189c7d527a8a0f12d4c9a59f52918001ce564..ac95b570c4ec4f469d6d6ceda0c6c13b3bdd9d29 100644
--- a/googledatastore/conf/googledatastore.properties
+++ b/googledatastore/conf/googledatastore.properties
@@ -34,10 +34,10 @@ readallfields = true
 
 ## Optional parameters
 #
-# Decides the consistency level of read requests. Acceptable value is:
-# EVENTUAL, STRONG (default is EVENTUAL)
+# Decides the consistency level of read requests. Acceptable values are:
+# EVENTUAL, STRONG (default is STRONG)
 #
-# googledatastore.readConsistency=EVENTUAL
+# googledatastore.readConsistency=STRONG
 
 # Decides how we group entities into entity groups. 
 # (See the details section in README.md for documentation)
diff --git a/googledatastore/pom.xml b/googledatastore/pom.xml
index 19abce650a4cfb5a17a3d3bd325349da893653e2..e7ab3eac4c9f9b57bb2d63d8ab3499df3ae63586 100644
--- a/googledatastore/pom.xml
+++ b/googledatastore/pom.xml
@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <!-- 
-Copyright (c) 2012 - 2015 YCSB contributors. All rights reserved.
+Copyright (c) 2015 YCSB contributors. All rights reserved.
 
 Licensed under the Apache License, Version 2.0 (the "License"); you
 may not use this file except in compliance with the License. You
diff --git a/googledatastore/src/main/java/com/yahoo/ycsb/db/package-info.java b/googledatastore/src/main/java/com/yahoo/ycsb/db/package-info.java
index c0560d64409668d71f6c6cb97ba1972a3d2e060d..bccdf1e648e6b9cab0f7c84660c2e884efa2a5db 100644
--- a/googledatastore/src/main/java/com/yahoo/ycsb/db/package-info.java
+++ b/googledatastore/src/main/java/com/yahoo/ycsb/db/package-info.java
@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2015 Google Inc. All rights reserved.
+ * Copyright (c) 2015 YCSB contributors. All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License"); you
  * may not use this file except in compliance with the License. You
diff --git a/googledatastore/src/main/java/com/yahoo/ycsb/db/GoogleDatastoreClient.java b/googledatastore/src/main/java/com/yahoo/ycsb/db/GoogleDatastoreClient.java
index f2f6441022e2105cb87483ebe1d07ee5b673e85a..9e086699da3503d26cbb4e3e4be61eed9251e46f 100644
--- a/googledatastore/src/main/java/com/yahoo/ycsb/db/GoogleDatastoreClient.java
+++ b/googledatastore/src/main/java/com/yahoo/ycsb/db/GoogleDatastoreClient.java
@@ -1,5 +1,5 @@
 /*
- * Copyright 2015 Google Inc. All Rights Reserved.
+ * Copyright 2015 YCSB contributors. All Rights Reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License"); you
  * may not use this file except in compliance with the License. You
@@ -49,7 +49,6 @@ import javax.annotation.Nullable;
 
 /**
  * Google Cloud Datastore Client for YCSB.
- * Author: stfeng@
  */
 
 public class GoogleDatastoreClient extends DB {
@@ -73,9 +72,9 @@ public class GoogleDatastoreClient extends DB {
   private static Logger logger =
       Logger.getLogger(GoogleDatastoreClient.class);
 
-  // Read consistency defaults to "eventual" (this is the same as other
-  // DB client, such as DynamoDB). User can override this via configure.
-  private ReadConsistency readConsistency = ReadConsistency.EVENTUAL;
+  // Read consistency defaults to "STRONG" per YCSB guidance.
+  // User can override this via configure.
+  private ReadConsistency readConsistency = ReadConsistency.STRONG;
 
   private EntityGroupingMode entityGroupingMode =
       EntityGroupingMode.ONE_ENTITY_PER_GROUP;
@@ -172,11 +171,13 @@ public class GoogleDatastoreClient extends DB {
 
     } catch (GeneralSecurityException exception) {
       throw new DBException("Security error connecting to the datastore: " +
-            exception.getMessage());
+            "cause: " + exception.getCause() +
+            " details: " + exception.getMessage());
 
     } catch (IOException exception) {
       throw new DBException("I/O error connecting to the datastore: " +
-            exception.getMessage());
+            "cause: " + exception.getCause() +
+            " details: " + exception.getMessage());
     }
 
     logger.info("Datastore client instance created: " +